##  Step 6: Install Chart.js
To be able to generate charts for your custom reports, install a charting library.
**Note**
The power of SAP LeanIX custom reports lies in their flexibility. The framework doesn't limit you to a specific charting library – you can select the one you prefer. In our tutorials, we use the [Chart.js![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.chartjs.org%2Fdocs%2Flatest%2F "https://www.chartjs.org/docs/latest/") library. For complete setup instructions, refer to the [Chart.js documentation![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.chartjs.org%2Fdocs%2Flatest%2Fgetting-started%2F "https://www.chartjs.org/docs/latest/getting-started/").
To install Chart.js, run the following command:

```
npm install chart.js
```



